package com.taauav.front.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.common.bean.Response;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.StringUtils;
import com.taauav.front.constant.UserAdminConstant;
import com.taauav.front.entity.UserAdmin;
import com.taauav.front.entity.UserAuthGroup;
import com.taauav.front.mapper.UserAdminMapper;
import com.taauav.front.mapper.UserAuthGroupMapper;
import com.taauav.front.service.IUserAdminService;
import com.taauav.front.service.IUserAuthGroupService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 外包人员表 服务实现类
 * </p>
 *
 * @author 鲲鹏
 * @since 2020-05-14
 */
@Service
public class UserAdminServiceImpl extends BaseServiceImpl<UserAdminMapper, UserAdmin> implements IUserAdminService {

    @Autowired
    private UserAdminMapper userAdminMapper;
    @Value("${server.IMAGE_URL}")
    private String imageUrl;

    @Autowired
    private Response response;

    @Autowired
    private UserAuthGroupMapper userAuthGroupMapper;

    @Autowired
    private IUserAuthGroupService userAuthGroupService;

    /**
     * 根据用户名获取人员信息
     *
     * @param username 用户名
     * @return
     */
    @Override
    public UserAdmin findByUsername(String username) {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("username", username);
        wrapper.eq("mark", 1);
        UserAdmin admin = userAdminMapper.selectOne(wrapper);
        if (admin != null && !"".equals(admin.getAvatar())) {
            admin.setAvatar(imageUrl + admin.getAvatar());
        }
        return admin;
    }

    /**
     * 获取人员列表
     *
     * @return
     */
    @Override
    public Response getUserAdminList() {
        // 查询条件
        QueryWrapper<UserAdmin> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", 1);
        queryWrapper.eq("mark", 1);
        List<UserAdmin> userAdminList = userAdminMapper.selectList(queryWrapper);
        return response.success(userAdminList);
    }

    /**
     * 根据人员ID获取人员信息
     *
     * @param id 人员ID
     * @return
     */
    @Override
    public UserAdmin getAdminInfo(Integer id) {
        if (id <= 0) {
            return null;
        }
        UserAdmin admin = userAdminMapper.selectById(id);
        if (admin == null) {
            return null;
        }
        //处理头像
        if (!"".equals(admin.getAvatar())) {
            admin.setAvatar(imageUrl + admin.getAvatar());
        }
        //处理角色名称
        if (!StringUtils.isEmpty(admin.getAuthGroup())) {
            UserAuthGroup userAuthGroup = userAuthGroupMapper.selectById(Integer.valueOf(admin.getAuthGroup()));
            admin.setAuthGroupText(userAuthGroup.getName());
        }
        //处理状态名称
        String statusText = FunctionUtils.getArrayText(String.valueOf(admin.getStatus()), UserAdminConstant.getAdminStatus());
        admin.setStatusText(statusText);
        return admin;
    }
}
